## Development installation

Install packaging/distribution tools:

```shell
pip install hatch twine
```

Install linter

```shell
pip install black
```

From top-level repo directory, install the package in editable mode:

```shell
pip install -e .
```

Local edits to the package will immediately take effect.